@@ -13,6 +13,7 @@
 # limitations under the License.
 
 import os
+import json
 from platformdirs import PlatformDirs
 import typer
 import sys
@@ -25,7 +26,7 @@ import pkgutil
 
 from .utils.fetch_data import FetchData
 from .utils.processing import get_format_type, out_dir_exists_check, \
-    appdir_exists_check, check_cli_outdated
+     appdir_builder, appdir_config_info, check_cli_outdated
 from fichub_cli import __version__
 
 init(autoreset=True)  # colorama init
@@ -33,19 +34,19 @@ timestamp = datetime.now().strftime("%Y-%m-%d T%H%M%S")
 
 app = typer.Typer(add_completion=False)
 app_dirs = PlatformDirs("fichub_cli", "fichub")
-
 discovered_plugins = {
     name: importlib.import_module(name)
     for finder, name, ispkg
     in pkgutil.iter_modules()
     if name.startswith('fichub_cli_')
 }
-
 for plugin in discovered_plugins.values():
-    app.add_typer(plugin.app)
+    if not plugin.__name__.endswith("-script"):
+        app.add_typer(plugin.app)
+
+# build/update the app directory & the config file
+appdir_builder(app_dirs)
 
-# check if app directory exists, if not, create it
-appdir_exists_check(app_dirs)
 # check if the cli is outdated
 check_cli_outdated("fichub-cli", __version__)
 
@@ -70,7 +71,7 @@ def default(
         "", "-o", " --out-dir", help="Path to the Output directory for files (default: Current Directory)"),
 
     format: str = typer.Option(
-        "epub", help="Download Format: epub (default), mobi, pdf or html"),
+        "epub", help="Download Formats, comma separated if multiple: epub (default), mobi, pdf or html"),
 
     force: bool = typer.Option(
         False, "--force", help="Force overwrite of an existing file", is_flag=True),
@@ -87,6 +88,12 @@ def default(
     debug_log: bool = typer.Option(
         False, "--debug-log", help="Save the logfile for debugging", is_flag=True),
 
+    config_init: bool = typer.Option(
+        False, "--config-init", help="Initialize the CLI config files", is_flag=True),
+
+    config_info: bool = typer.Option(
+        False, "--config-info", help="Show the CLI config info", is_flag=True),
+
     automated: bool = typer.Option(
         False, "-a", "--automated", help="For internal testing only", is_flag=True, hidden=True),
 
@@ -103,6 +110,14 @@ def default(
     Failed downloads will be saved in the `err.log` file in the current directory
     """
 
+    if config_init:
+        # initialize/overwrite the config files
+        appdir_builder(app_dirs, True)
+
+    if config_info:
+        # show the config files and info
+        appdir_config_info(app_dirs)
+
     # Check if the output directory exists if input is given
     if not out_dir == "":
         out_dir_exists_check(out_dir)
@@ -124,18 +139,20 @@ def default(
 
     format_type = get_format_type(format)
     if infile:
-        fic = FetchData(format_type, out_dir, force, debug, changelog,
-                        automated, verbose)
+        fic = FetchData(format_type=format_type, out_dir=out_dir, force=force,
+                        debug=debug, changelog=changelog,
+                        automated=automated, verbose=verbose)
         fic.get_fic_with_infile(infile)
 
     elif list_url:
-        fic = FetchData(format_type, out_dir, force, debug, changelog,
-                        automated, verbose)
+        fic = FetchData(format_type=format_type, out_dir=out_dir, force=force,
+                        debug=debug, changelog=changelog,
+                        automated=automated, verbose=verbose)
         fic.get_fic_with_list(list_url)
 
     elif url:
-        fic = FetchData(format_type, out_dir, force,
-                        debug, automated, verbose)
+        fic = FetchData(format_type=format_type, out_dir=out_dir, force=force,
+                        debug=debug, automated=automated, verbose=verbose)
         fic.get_fic_with_url(url)
 
     if version:
@@ -173,15 +190,22 @@ To report issues upstream for these sites, visit https://fichub.net/#contact
         if fic.exit_status == 1:
             typer.echo(
                 Fore.RED +
-                "\nThe CLI ran into some errors! Check " + Style.RESET_ALL +
-                Fore.YELLOW + "err.log" + Style.RESET_ALL + Fore.RED +
-                " in the current directory!" + Style.RESET_ALL)
+                "\nThe CLI ran into some errors! Check the console for the log messages!" + Style.RESET_ALL)
 
         if os.path.exists("output.log"):
-            rm_output_log = typer.confirm(
-                Fore.BLUE+"Delete the output.log?", abort=False, show_default=True)
-            if rm_output_log is True:
+            with open(os.path.join(app_dirs.user_data_dir, "config.json"), 'r') as f:
+                config = json.load(f)
+            
+            if config["delete_output_log"] == "":
+                rm_output_log = typer.confirm(
+                    Fore.BLUE+"Delete the output.log?", abort=False, show_default=True)
+                if rm_output_log is True:
+                    os.remove("output.log")
+            elif config["delete_output_log"] == "true":
                 os.remove("output.log")
+            elif config["delete_output_log"] == "false":
+                pass
+
 
         sys.exit(fic.exit_status)
 
